==> antragsgruen-3.7.1.tar.bz2: antragsgruen-3.7.1/messages/fr/export.php <==
<?php

return [
    'Page'                  => 'Page',
    'Initiators'            => 'Auteur',
    'introduction'          => 'Motion pour...',
    'InitiatorSingle'       => 'Auteur',
    'InitiatorMulti'        => 'Auteurs',
    'ResolutionDate'        => 'Date de la résolution',
    'AgendaItem'            => 'Point à l\'ordre du jour',
    'TopicSingle'           => 'Sujet',
    'TopicMulti'            => 'Sujets',
    'all_motions_title'     => 'Toutes les motions',
    'all_amendments_title'  => 'Tous les amendements',
    'title'                 => 'Titre',
    'draft'                 => 'Brouillon',
    'motion'                => 'Motion',
    'misc'                  => 'Other',
    'motions'               => 'Motions',
    'amendments'            => 'Amendements',
    'line'                  => 'Ligne',
    'amend_change'          => 'Changement',
    'amend_reason'          => 'Justification',
    'motion_reason'         => 'Explication',
    'agenda_item'           => 'Ordre du jour',
    'prefix_short'          => 'Préfixe',
    'initiator'             => 'Auteur',
    'text'                  => 'Texte',
    'tags'                  => 'Tags',
    'contact'               => 'Contact',
    'procedure'             => 'Procédure',
    'mail_motion_x'         => 'motion %MOTION%',
    'mail_amendment_x_to_y' => 'amendement %AMENDMENT% à la motion %MOTION%',
    'mail_body'             => "Salut %NAME%,\n\nJe te contacte au sujet de ta motion %MOTION%, pour laquelle je suis responsable.",
    'filename_amendments'   => 'Amendement',
    'filename_motions'      => 'Motion',
    'incl_withdrawn'        => 'Dont retiré',
    'btn_openslides'        => 'Openslides',
    'btn_amendments'        => 'Amendements',
];

==> antragsgruen-3.7.3.tar.bz2: antragsgruen-3.7.3/messages/fr/export.php <==
<?php

return [
    'Page'                  => 'Page',
    'Initiators'            => 'Auteur',
    'introduction'          => 'Motion pour...',
    'InitiatorSingle'       => 'Auteur',
    'InitiatorMulti'        => 'Auteurs',
    'ResolutionDate'        => 'Date de la résolution',
    'AgendaItem'            => 'Point à l\'ordre du jour',
    'TopicSingle'           => 'Sujet',
    'TopicMulti'            => 'Sujets',
    'all_motions_title'     => 'Toutes les motions',
    'all_amendments_title'  => 'Tous les amendements',
    'title'                 => 'Titre',
    'draft'                 => 'Brouillon',
    'motion'                => 'Motion',
    'misc'                  => 'Other',
    'motions'               => 'Motions',
    'amendments'            => 'Amendements',
    'line'                  => 'Ligne',
    'amend_change'          => 'Changement',
    'amend_reason'          => 'Justification',
    'motion_reason'         => 'Explication',
    'agenda_item'           => 'Ordre du jour',
    'prefix_short'          => 'Préfixe',
    'initiator'             => 'Auteur',
    'text'                  => 'Texte',
    'tags'                  => 'Tags',
    'contact'               => 'Contact',
    'procedure'             => 'Procédure',
    'mail_motion_x'         => 'motion %MOTION%',
    'mail_amendment_x_to_y' => 'amendement %AMENDMENT% à la motion %MOTION%',
    'mail_body'             => "Salut %NAME%,\n\nJe te contacte au sujet de ta motion %MOTION%, pour laquelle je suis responsable.",
    'filename_amendments'   => 'Amendement',
    'filename_motions'      => 'Motion',
    'incl_inactive'         => 'Dont retiré',
    'btn_openslides'        => 'Openslides',
    'btn_amendments'        => 'Amendements',
];
